@@ -12,7 +12,7 @@ def export_excel(data: List[Dict], config: ExcelConfiguration, update_time):
         zip(data, config.sheets.values())
     ):
         ws = wb.active if n == 0 else wb.create_sheet()
-        write_sheet(ws, ws_data, ws_config, update_time)
+        write_sheet(ws, ws_data, ws_config, update_time, config.update_message)
     virtual_file = BytesIO()
     wb.save(virtual_file)
     virtual_file.seek(0)
